remove unnecessary null pointer check
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index a4e3f96..a6572c5 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -46,12 +46,14 @@ enum
        UCI_ERR_LAST
 };
 
+struct uci_list;
 struct uci_list
 {
-       void *next;
-       void *prev;
+       struct uci_list *next;
+       struct uci_list *prev;
 };
 
+struct uci_element;
 struct uci_package;
 struct uci_section;
 struct uci_option;
@@ -60,14 +62,14 @@ struct uci_parse_context;
 
 
 /**
* uci_alloc: Allocate a new uci context
  */
-extern struct uci_context *uci_alloc(void);
+extern struct uci_context *uci_alloc_context(void);
 
 /**
* uci_free: Free the uci context including all of its data
  */
-extern void uci_free(struct uci_context *ctx);
+extern void uci_free_context(struct uci_context *ctx);
 
 /**
  * uci_perror: Print the last uci error that occured
@@ -120,6 +122,20 @@ extern int uci_unload(struct uci_context *ctx, const char *name);
 extern int uci_cleanup(struct uci_context *ctx);
 
 /**
+ * uci_lookup: Look up an uci element
+ *
+ * @ctx: uci context
+ * @res: where to store the result
+ * @package: config package
+ * @section: config section (optional)
+ * @option: option to search for (optional)
+ *
+ * If section is omitted, then a pointer to the config package is returned
+ * If option is omitted, then a pointer to the config section is returned
+ */
+extern int uci_lookup(struct uci_context *ctx, struct uci_element **res, char *package, char *section, char *option);
+
+/**
  * uci_list_configs: List available uci config files
  *
  * @ctx: uci context
@@ -60,14 +62,14 @@ struct uci_parse_context;
 
 /**
- * uci_alloc: Allocate a new uci context
+ * uci_alloc_context: Allocate a new uci context
  */
@@ -60,14 +62,14 @@ struct uci_parse_context;
 
 /**
- * uci_free: Free the uci context including all of its data
+ * uci_free_context: Free the uci context including all of its data
  */